"""This is the "rcknester.py" module and it provides one function called
print_lol() which prints lists that may or may not include nested lists."""

def print_lol(the_list, indent=False, level=0):
    """This function takes one positional argument called "the_list",
    which is any Python list (of - possibly - nested lists). Each data item in the
    provided list is (recursively) printed to the screen on it's own line."""

    for each_item in the_list:
        if isinstance(each_item, list):
            print_lol(each_item, level+1)
        else:
            if indent:
                for tab_stop in range(level):
                    print("\t", end="")
            print(each_item)



from distutils.core import setup
	
setup(
    name = "rcknester",
    version = "1.2.0",
    py_modules = ["rcknester"],
    author = "hfpython",
    author_email = "hfpython@headfirstlabs.com",
    url = "http://www.headfirstlabs.com",
    description = "A simple printer of nested lists"
)	
